@@ -5,7 +5,6 @@ from ...lib.types import INF
 
 from .ap import aplib
 from .bz2 import bz2
-from .gz import gz
 from .lz import lzma
 from .lznt1 import lznt1
 from .zl import zl
@@ -40,7 +39,7 @@ class decompress(Unit):
             raise ValueError('The compression factor must be nonnegative.')
         super().__init__(tolerance=tolerance, prepend=prepend, min_ratio=min_ratio)
         self.engines = [
-            engine() for engine in [zl, lzma, aplib, gz, bz2, lz4, lznt1]
+            engine() for engine in [zl, lzma, aplib, bz2, lz4, lznt1]
         ]
 
     def process(self, data):
